package metier;
import java.util.Objects;
import javax.swing.Icon;
import javax.swing.JOptionPane;

/**
 * Classe Mère Personnage
 * @author Dominique_2
 * @version 20210311
 */
public class Personnage {
    // Variables membres
    private String nom;    
    private String img;      
    private int energie;
    private int dureeVie;
    /**
     * Valorisation des variables membres
     * @param nom       nom du personnage
     * @param img       nom de l'image du personnage
     * @param energie   valeur énergétique  
     * @param dureeVie  durée de vie, en année 
     */
    public Personnage(String nom, String img, int energie, int dureeVie) {
        this.nom = nom;
        this.img = img;
        this.energie = energie;
        this.dureeVie = dureeVie;
    }
    /**
     * Permet d'obtenir les valeurs des attributs de l'objet courant
     * @return liste des attributs avec leurs valeurs
     */
    @Override
    public String toString() {
        return "Personnage{" + "nom=" + nom + ", img=" + img + ", energie=" + energie + ", dureeVie=" + dureeVie + '}';
    }
    
    @Override
    public int hashCode() {
        int hash = 3;
        hash = 47 * hash + Objects.hashCode(this.nom);
        hash = 47 * hash + Objects.hashCode(this.img);
        hash = 47 * hash + this.energie;
        hash = 47 * hash + this.dureeVie;
        return hash;
    }
    
    /**
     * Comparaison de l'objet courant avec l'objet passé en paramètre
     * @param obj objet à comparer avec l'objet courant
     * @return true : les 2 objets sont identiques, false sinon
     */
    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Personnage other = (Personnage) obj;
        if (this.energie != other.energie) {
            return false;
        }
        if (this.dureeVie != other.dureeVie) {
            return false;
        }
        if (!Objects.equals(this.nom, other.nom)) {
            return false;
        }
        if (!Objects.equals(this.img, other.img)) {
            return false;
        }
        return true;
    }

    /**
     * Get the value of energie     *
     * @return the value of energie
     */
    public int getEnergie() {
        return energie;
    }

    /**
     * Set the value of energie     *
     * @param energie new value of energie
     */
    public void setEnergie(int energie) {
        this.energie = energie;
    }
  
     /**
     * Get the value of dureeVie     *
     * @return the value of dureeVie
     */
    public int getDureeVie() {
        return dureeVie;
    }

    /**
     * Set the value of dureeVie     *
     * @param dureeVie new value of dureeVie
     */
    public void setDureeVie(int dureeVie) {
        this.dureeVie = dureeVie;
    }

    /**
     * Get the value of img     *
     * @return the value of img
     */
    public String getImg() {
        return img;
    }

    /**
     * Set the value of img     *
     * @param img new value of img
     */
    public void setImg(String img) {
        this.img = img;
    }


    /**
     * Get the value of nom     *
     * @return the value of nom
     */
    public String getNom() {
        return nom;
    }

    /**
     * Set the value of nom     *
     * @param nom new value of nom
     */
    public void setNom(String nom) {
        this.nom = nom;
    }
    
    /**
     * Rencontre avec un autre personnage 
     * @param unPerso : personnage rencontré
     * @return 
     */
    public void rencontrer(Personnage unPerso) {
        String titre = this.getNom() + " rencontre " + unPerso.getNom();
        String message = "Bonjour " + unPerso.getNom() + " !";        
        JOptionPane.showMessageDialog(null, message, titre, JOptionPane.INFORMATION_MESSAGE);
        String source = "/img/" + this.getImg();
        Icon imgPerso = new javax.swing.ImageIcon(getClass().getResource(source));
        JOptionPane.showMessageDialog(null, message, titre, JOptionPane.INFORMATION_MESSAGE, imgPerso);  
    }  
    
    /**
     * Rencontre avec un autre personnage 
     * @param unPerso personnage à saluer
     */
    public void saluer(Personnage unPerso) {
        String titre = this.getNom() + " salue " + unPerso.getNom();
        String message = "Bonjour " + unPerso.getNom() + ", \nje suis content de te revoir!";  
        JOptionPane.showMessageDialog(null, message, titre, JOptionPane.INFORMATION_MESSAGE);
    }
    
    /**
     * Ajout du nombre passé en paramètre à l'énergie
     * Si le résultat de l'ajout est négatif, il est forcé à 0
     * @param nb ; nombre à ajouter (positif ou négatif)
     */
    public void varierEnergie(int nb){
        energie = energie+nb > 0 ? energie+nb : 0;
    }
    
    /**
     * Ajout du nombre passé en paramètre à la durée de vie
     * Si le résultat de l'ajout est négatif, il est forcé à 0
     * @param nb ; nombre à ajouter (positif ou négatif)
     */
    public void varierDureeVie(int nb){
        dureeVie = dureeVie+nb > 0 ? dureeVie+nb : 0;
    }
    
        public void combattre(Personnage unPerso) {
     if(unPerso.getEnergie()==0){
         String titre = this.getNom() + " veut combattre " + unPerso.getNom();
        String message = "Aide moi..."+ getNom() +" Je n'ai plus d'énérgie"  ;        
        JOptionPane.showMessageDialog(null, message, titre, JOptionPane.INFORMATION_MESSAGE);
     }
  }
}
