package metier;

import java.util.ArrayList;
import java.util.Objects;
import javax.swing.Icon;
import javax.swing.JOptionPane;
import static javax.swing.JOptionPane.QUESTION_MESSAGE;

/**
 * Classe Sorier, hérite de la classe Personnage
 * @author Dominique_2
 * @version 20210318
 */
public class Sorcier  extends Personnage {
    
    private String baguette;
    private ArrayList<Enigme> lesEnigmes;

    /**
     * Valorisation des variables membres
     * @param nom       nom du sorcier
     * @param img       nom de l'image représentant le sorcier
     * @param energie   valeur énergétique du sorcier
     * @param dureeVie  durée de vie du sorcier
     * @param baguette  baguette du sorcier  
     * @param e         inutile désormais
     */
    public Sorcier(String nom, String img, int energie, int dureeVie, String baguette, String e) {
        super(nom, img, energie, dureeVie);
        this.lesEnigmes = new ArrayList<>();
        this.baguette = baguette;        
    }
    
     /**
     * Valorisation des variables membres
     * @param nom       nom du sorcier
     * @param img       nom de l'image représentant le sorcier
     * @param energie   valeur énergétique du sorcier
     * @param dureeVie  durée de vie du sorcier
     * @param baguette  baguette du sorcier  
     */
    public Sorcier(String nom, String img, int energie, int dureeVie, String baguette) {
        super(nom, img, energie, dureeVie);
        this.lesEnigmes = new ArrayList<>();
        this.baguette = baguette;        
    }

    @Override
    public int hashCode() {
        int hash = 7;
        hash = super.hashCode() + (73 * hash + Objects.hashCode(this.baguette));
        return hash;
    }

    /**
     * Comparaison de l'objet courant avec l'objet passé en paramètre
     * @param obj objet à comparer avec l'objet courant
     * @return true : les 2 objets sont identiques, false sinon
     */
    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Sorcier other = (Sorcier) obj;
        if (!Objects.equals(this.baguette, other.baguette)) {
            return false;
        }
        if (!Objects.equals(this.lesEnigmes, other.lesEnigmes)) {
            return false;
        }
        if (!super.equals(obj)) {
            return false;            
        }
        return true;
    }

    /**
     * Permet d'obtenir les valeurs des attributs de l'objet courant
     * @return liste des attributs avec leurs valeurs
     */
    @Override
    public String toString() {
        return super.toString() + "\n\tSorcier{" + "baguette=" + baguette + ", nb enigmes = " + getLesEnigmes().size() +'}';
    }
        
    /**
     * Get the value of baguette     *
     * @return the value of baguette
     */
    public String getBaguette() {
        return baguette;
    }

    /**
     * Set the value of baguette     *
     * @param baguette new value of baguette
     */
    public void setBaguette(String baguette) {
        this.baguette = baguette;
    }

    public ArrayList<Enigme> getEnigme() {
        return getLesEnigmes();
    }

    /**
     * Rencontre avec un autre personnage 
     * @param unPerso personnage à saluer
     */
    public void saluer(Personnage unPerso) {
        String titre = this.getNom() + " salue " + unPerso.getNom();
        String message = "Bonjour " + unPerso.getNom() + ", \nje t'ai jeté un sort, tu es désormais sous ma dépendance!";  
        JOptionPane.showMessageDialog(null, message, titre, JOptionPane.INFORMATION_MESSAGE);
    }
    
    /**
     * Ajout de l'énigme passée en paramètre dans la collection les Enigmes
     * @param e Enigme
     */
    public void ajouterEnigme(Enigme e) {
        getLesEnigmes().add(e);
    }
    
    public void rencontrer(Personnage p) {
        int indiceEnigme = Jeu.genererNbAleatoire(0, getLesEnigmes().size()-1);
        String titre = this.getNom() + " rencontre " + p.getNom();
        String reponse = JOptionPane.showInputDialog(    
                                        null, 
                                        getLesEnigmes().get(indiceEnigme).getQuestion(), 
                                        titre + " : énigme", 
                                        QUESTION_MESSAGE);
        String resultat="";
        int type;
        if (getLesEnigmes().get(indiceEnigme).getReponse().equals(reponse)) {
            resultat = "Bonne réponse, tu peux passer ton chemin!";
            type = JOptionPane.INFORMATION_MESSAGE;
            p.varierDureeVie(1);
        } else {
            resultat =  "Mauvaise réponse, "
                    +   "\nattention à toi " + p.getNom() +", "
                    +   "\nta vie est en danger!";
            type = JOptionPane.WARNING_MESSAGE;
            p.varierDureeVie(-2);
        }
        varierEnergie(-1);
        Icon iMagie = new javax.swing.ImageIcon(getClass().getResource("/img/magie.jpg"));
        JOptionPane.showMessageDialog(null, resultat, titre + " : résultat",type, iMagie); 
    }

    /**
     * @return the lesEnigmes
     */
    public ArrayList<Enigme> getLesEnigmes() {
        return lesEnigmes;
    }
}
