package metier;

import java.util.Objects;
import javax.swing.Icon;
import javax.swing.JOptionPane;
import static javax.swing.JOptionPane.DEFAULT_OPTION;
import static javax.swing.JOptionPane.QUESTION_MESSAGE;

/**
 *
 * @author Dominique_2
 */
public class Voleur extends Personnage{
    
    private String outil;
    String [] outils = {"Pierre", "Feuille", "Ciseaux"};
    
    /**
     * Valorisation des variables membres
     * @param nom       nom du guerrier
     * @param img       nom de l'image représentant le guerrier
     * @param energie   valeur énergétique du guerrier
     * @param dureeVie  durée de vie du guerrier
     * @param outil     outil du guerrier
     */
    public Voleur(String nom, String img, int energie, int dureeVie, String outil) {
        super(nom, img, energie, dureeVie);
        this.outil = outil;            
    }

    @Override
    public int hashCode() {
        int hash = 7;
        hash = super.hashCode() + (29 * hash + Objects.hashCode(this.outil));
        return hash;
    }

    /**
     * Comparaison de l'objet courant avec l'objet passé en paramètre
     * @param obj objet à comparer avec l'objet courant
     * @return true : les 2 objets sont identiques, false sinon
     */
    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Voleur other = (Voleur) obj;       
        if (!Objects.equals(this.outil, other.outil)) {
            return false;
        }
        if (!super.equals(obj)) {
            return false;
        }        
        return true;
    }

    /**
     * Permet d'obtenir les valeurs des attributs de l'objet courant
     * @return liste des attributs avec leurs valeurs
     */
    @Override
    public String toString() {
        return super.toString() + "\n\tVoleur{" + "outil=" + outil + '}';
    }
   
    /**
     * Get the value of outil     *
     * @return the value of outil
     */
    public String getOutil() {
        return outil;
    }

    /**
     * Set the value of outil     *
     * @param outil new value of outil
     */
    public void setOutil(String outil) {
        this.outil = outil;
    }
    
    public void rencontrer(Personnage p) {
//        int indiceOutil = Jeu.genererNbAleatoire(0, outils.length -1);
        Icon iPFC = new javax.swing.ImageIcon(getClass().getResource("/img/pierreFeuilleCiseaux.jpg"));
//        String reponse = (String) JOptionPane.showInputDialog(    
//                null,
//                "Pierre, feuille, ciseaux ? ",
//                "Quel est ton choix ?" + p.getNom(),
//                QUESTION_MESSAGE, iPFC,
//                outils,"");
        int nbJeu = 0;
        String mess = "Que choisis-tu \n" + p.getNom() + " ?";
        String titre = this.getNom() + " rencontre " + p.getNom();
        int rep=-1, indiceOutil=-1;
        while (rep == indiceOutil) {
            if (nbJeu > 0) {                
                mess = "Égalité, rejoue vite!";
            }
            indiceOutil = Jeu.genererNbAleatoire(0, outils.length -1);
            rep = JOptionPane.showOptionDialog(
                    null, 
                    mess, 
                    titre,
                    DEFAULT_OPTION,
                    QUESTION_MESSAGE, 
                    iPFC, 
                    outils, 
                    0);
            nbJeu++;
        }
        boolean gagne = true;          // Position du personnage rencontré
        String explication = "";
        switch (indiceOutil) {
            case 0 :                    // Cas Pierre
                if (rep == 2) {         // Cas Ciseaux
                    gagne = false;      // La pierre aiguise les ciseaux
                    explication = "La pierre aiguise les ciseaux";
                }
                break;
            case 1 :                    // Cas Feuille
                if (rep == 0) {         // Cas Pierre
                    gagne = false;      // La feuille bat la pierre en l'enveloppant   
                    explication = "La feuille enveloppe la pierre";                }
                break;
            case 2 :                    // Cas Ciseaux
                if (rep == 1) {         // Cas Feuille
                    gagne = false;      // Les ciseaux coupent la feuille
                    explication = "Les ciseaux coupent la feuille";
                }
        }
        mess = "J'ai choisi " + outils[indiceOutil] + " et toi " + outils[rep] + "\n" + explication + "\n\n";
        mess +=  gagne ? 
                "Aujourd'hui tu as gagné "+p.getNom()+",\n mais qu'en sera-t-il demain ?" :
                "Ah, ah, ah ! Perdu pour toi "+p.getNom()+".\nAu plaisir de te revoir...";
        JOptionPane.showMessageDialog(null, mess, titre + " : résultat",0, iPFC); 
        
        if (!gagne) {
            p.varierDureeVie(-1);
            p.varierEnergie(-1);
        } else {
            p.varierEnergie(1);
            varierEnergie(-1);
        }        
    }    

}
